<?php

namespace Amazingcat\ProductModal\Block\Product\View;

use Magento\Catalog\Block\Product\{Image, ImageBuilder};
use Magento\Catalog\Api\Data\ProductInterface;
use Magento\Checkout\Helper\Cart as CartHelper;
use Magento\Directory\Model\Currency;
use Magento\Framework\App\ActionInterface;
use Magento\Framework\Data\Form\FormKey;
use Magento\Framework\Registry;
use Magento\Framework\Url\Helper\Data;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Magento\Quote\Api\Data\{CartInterface, CartItemInterface};

class Display extends Template
{
    /**
     * @var string
     */
    protected const PRODUCT_IMAGE_ID = 'category_page_grid';

    /**
     * @var Currency
     */
    protected $currency;

    /**
     * @var Registry
     */
    protected $coreRegistry;

    /**
     * @var Cart
     */
    protected $cart;

    /**
     * @var ImageBuilder
     */
    protected $imageBuilder;

    /**
     * @var Data
     */
    protected $urlHelper;

    /**
     * @var CartHelper
     */
    protected $cartHelper;

    /**
     * @var FormKey
     */
    protected $formKey;

    /**
     * @var ProductInterface|null
     */
    protected $product = null;

    /**
     * @var CartItemInterface|null
     */
    protected $quoteItem = null;

    /**
     * @var int
     */
    protected $qty = 1;

    /**
     * Display constructor.
     *
     * @param Context       $context
     * @param Currency      $currency
     * @param Registry      $registry
     * @param CartInterface $cart
     * @param ImageBuilder  $imageBuilder
     * @param Data          $urlHelper
     * @param FormKey       $formKey
     * @param array         $data
     */
    public function __construct(
        Context $context,
        Currency $currency,
        Registry $registry,
        CartInterface $cart,
        ImageBuilder $imageBuilder,
        Data $urlHelper,
        CartHelper $cartHelper,
        FormKey $formKey,
        array $data = []
    ) {
        parent::__construct($context, $data);

        $this->currency = $currency;
        $this->coreRegistry = $registry;
        $this->cart = $cart;
        $this->imageBuilder = $imageBuilder;
        $this->urlHelper = $urlHelper;
        $this->cartHelper = $cartHelper;
        $this->formKey = $formKey;

        $this->loadProduct();
    }

    protected function loadProduct()
    {
        $this->product = $this->coreRegistry->registry('product');
        $quoteItemId = (int)$this->getRequest()->getParam('quote-item-id');
        if (is_null($quoteItemId) || $quoteItemId === "null") {
            return;
        }

        $cartQuoteItems = $this->cart->getItems();
        if ($cartQuoteItems) {
            foreach ($cartQuoteItems as $item) {
                if ((int)$item->getId() === $quoteItemId) {
                    $this->quoteItem = $item;
                    $this->qty = $item->getQty();
                    break;
                }
            }
        }
    }

    /**
     * @return ProductInterface|null
     */
    public function getProduct()
    {
        return $this->product;
    }

    /**
     * @return Image
     */
    public function getImage()
    {
        return $this->imageBuilder->create($this->product, static::PRODUCT_IMAGE_ID, []);
    }

    /**
     * @return CartItemInterface|null
     */
    public function getQuoteItem()
    {
        return $this->quoteItem;
    }

    /**
     * @return int
     */
    public function getQty()
    {
        return $this->qty;
    }

    /**
     * @return string
     */
    public function getCurrentCurrencySymbol()
    {
        return $this->currency->getCurrencySymbol();
    }

    /**
     * @return array
     */
    public function getAddToCartPostParams()
    {
        $url = $this->cartHelper->getAddUrl($this->product, []);
        return [
            'action' => $url,
            'data' => [
                'product' => $this->product->getEntityId(),
                ActionInterface::PARAM_NAME_URL_ENCODED => $this->urlHelper->getEncodedUrl($url),
            ]
        ];
    }

    /**
     * @return string
     */
    public function getFormKey()
    {
        return $this->formKey->getFormKey();
    }
}
