<?php

namespace Amazingcat\ProductModal\Controller\Ajax;

use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\Checkout\Helper\Cart as CartHelper;
use Magento\Framework\App\Action\{Action, Context};
use Magento\Framework\Controller\{ResultFactory, ResultInterface};
use Magento\Quote\Api\Data\CartInterface;

class GetCartProduct extends Action
{
    /**
     * @var CartHelper
     */
    protected $cartHelper;

    /**
     * @var ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var CartInterface
     */
    protected $cart;

    /**
     * GetCartProduct constructor.
     *
     * @param Context                    $context
     * @param CartHelper                 $cartHelper
     * @param ProductRepositoryInterface $productRepository
     * @param CartInterface              $cart
     * @param array                      $data
     */
    public function __construct(
        Context $context,
        CartHelper $cartHelper,
        ProductRepositoryInterface $productRepository,
        CartInterface $cart,
        array $data = []
    ) {
        parent::__construct($context);

        $this->cartHelper = $cartHelper;
        $this->productRepository = $productRepository;
        $this->cart = $cart;
    }

    /**
     * @return ResultInterface
     */
    public function execute()
    {
        $resultJson = $this->resultFactory->create(ResultFactory::TYPE_JSON);

        $ids = $this->getRequest()->getParam('ids');
        $products_info = [];
        foreach ($ids as $id) {
            $items = $this->cart->getItems();
            if (isset($items)) {
                foreach ($items as $item) {
                    if ((int)$item->getId() === (int)$id) {
                        $product_id = $item->getProductId();
                        $product = $this->productRepository->getById($product_id);
                        $product_url = $product->getProductUrl();
                        $products_info["$id"] = [
                            'product_id'     => $product_id,
                            'product_url'    => $product_url,
                            'product_remove' => $this->cartHelper->getDeletePostJson($item)
                        ];
                    }
                }
            }
        }

        $resultJson->setData($products_info);
        return $resultJson;
    }
}
