<?php

namespace Amazingcat\ProductModal\Controller\Product;

use Amazingcat\ProductModal\Model\ProductChecker;
use Magento\Framework\App\Action\{Action, Context};
use Magento\Framework\Controller\Result\{Json, JsonFactory};

class Check extends Action
{
    /**
     * @var ProductChecker
     */
    protected $productChecker;

    /**
     * @var JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * Check constructor.
     *
     * @param Context        $context
     * @param ProductChecker $productChecker
     * @param JsonFactory    $resultJsonFactory
     */
    public function __construct(
        Context $context,
        ProductChecker $productChecker,
        JsonFactory $resultJsonFactory
    ) {
        parent::__construct($context);

        $this->productChecker = $productChecker;
        $this->resultJsonFactory = $resultJsonFactory;
    }

    /**
     * @return Json
     */
    public function execute()
    {
        $data = [
            'status'        => 404,
            'productUrl'    => '',
            'productUrlKey' => '',
        ];

        $productId = (int)$this->getRequest()->getParam('product_id');

        if (($product = $this->productChecker->check($productId)) !== null) {
            $data['status'] = 200;
            $data['productUrl'] = $product->getProductUrl();
            $data['productUrlKey'] = $product->getUrlKey();
        }

        $result = $this->resultJsonFactory->create();
        return $result->setData($data);
    }
}
