<?php

namespace Amazingcat\ProductModal\Observer;

use Magento\Catalog\Api\Data\ProductInterface;
use Magento\Framework\App\{RequestInterface, ResponseFactory};
use Magento\Framework\Event\{Observer, ObserverInterface};

class ProductView implements ObserverInterface
{
    /**
     * @var RequestInterface
     */
    protected $request;

    /**
     * @var ResponseFactory
     */
    protected $responseFactory;

    /**
     * ProductView constructor.
     *
     * @param RequestInterface $request
     * @param ResponseFactory  $responseFactory
     */
    public function __construct(
        RequestInterface $request,
        ResponseFactory $responseFactory
    ) {
        $this->request = $request;
        $this->responseFactory = $responseFactory;
    }

    /**
     * Returns category URL for a product.
     *
     * @param ProductInterface $product
     *
     * @return string|null
     */
    protected function getCategoryUrl($product)
    {
        $category = $product->getCategory();
        if (isset($category)) {
            return $category->getUrl();
        }

        $categoryIds = $product->getCategoryIds();
        $maxId = max($categoryIds);
        if ($maxId > 2) {
            $category = $product->getCategoryCollection()->getItemById($maxId);
            if (isset($category)) {
                return $category->getUrl();
            }
        }

        return null;
    }

    /**
     * Returns quick view URL for a product.
     *
     * @param ProductInterface $product
     *
     * @return string|null
     */
    protected function getQuickViewUrl($product)
    {
        $url = $this->getCategoryUrl($product);
        if (isset($url)) {
            return $url . '#product-' . $product->getId() . '-' . $product->getUrlKey();
        }

        return null;
    }

    /**
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $isIframe = $this->request->getParam('iframe');
        if ($isIframe) {
            return;
        }

        $product = $observer->getEvent()->getProduct();
        $url = $this->getQuickViewUrl($product);
        if (isset($url)) {
            $this->responseFactory->create()->setRedirect($url)->sendResponse();
            die();
        }
    }
}
