define([
    'jquery',
    'Amazingcat_ProductModal/js/url-params-parser',
    'Amazingcat_ProductModal/js/amazing-lib'
], function ($, urlParamsParser, amazingLib) {
    return function (config, element) {
        var location = window.parent.location.href;

        $(".pick-button", element).click(function () {
            if (!$(this).hasClass("pick-button-active")) {
                $(".pick-button-active", element).removeClass("pick-button-active");
                $(this).addClass("pick-button-active");
            }
        });

        $(".input-number", element).each(function () {
            var spinner = $(this),
                input = spinner.find("input[type='number']"),
                btnUp = spinner.find(".quantity-up"),
                btnDown = spinner.find(".quantity-down"),
                min = input.attr("min"),
                max = input.attr("max");

            btnUp.click(function () {
                var oldValue = parseFloat(input.val()),
                    newVal = oldValue;
                if (!max || oldValue < max) newVal = oldValue + 1;
                spinner.find("input").val(newVal);
                spinner.find("input").trigger("change");
            });

            btnDown.click(function () {
                var oldValue = parseFloat(input.val()),
                    newVal = oldValue;
                if (oldValue > min) newVal = oldValue - 1;
                spinner.find("input").val(newVal);
                spinner.find("input").trigger("change");
            });
        });


        var AddToCardlastSend = false;

        $(".add-item-btn .btn", element).click(function (event) {
            event.preventDefault();

            if (AddToCardlastSend !== false) {
                return false;
            }

            var $related_products = $("input[name='related_products[]']:checked", element);
            var related_products = $related_products.map(function () {
                return $(this).val();
            }).get().join(',');

            var $button = $(this);
            var $icon = $button.find('.add-item-btn--icon');
            var $wrapper = $("#product-wrapper", element);
            var $form = $wrapper.find('.product--right form');
            var $message = $form.find('.message');

            if ($message.length === 0) {
                $message = $('<div/>').hide().addClass('message').prependTo($form);
                $message.wrap('<div role="alert"/>')
            }

            var finish = function () {
                $button.removeClass("disabled");
                $icon.addClass('fa-plus-square').removeClass('fa-spinner fa-spin');
                AddToCardlastSend = false;
            };

            AddToCardlastSend = $.ajax({
                method: "POST",
                url: $('input[name="action"]', element).val(),
                data: {
                    product: config.productId,
                    quoteItemId: config.quoteItemId,
                    type: $('input[name="product_type"]', element).val(),
                    qty: $("#quick_view_product_qty", element).val(),
                    related_product: related_products,
                    flashMessage: 0,
                    form_key: $('input[name="form_key"]', element).val(),
                },
                dataType: "json",
                beforeSend: function () {
                    $button.addClass("disabled");
                    $icon.removeClass('fa-plus-square').addClass('fa-spinner fa-spin');
                    $message.removeClass('success error').hide();
                },
                success: function (result, status, xhr) {
                    var parentWindow = null;
                    var isInModal = element.ownerDocument !== document;

                    if (isInModal && !location.includes('/checkout') && xhr.status === 200) {
                        var doc = element.ownerDocument;
                        var win = doc.defaultView;
                        var parentDocument = win.parent.document;
                        parentWindow = win.parent.window;

                        parentWindow.jQuery(parentDocument).trigger('update-mini-cart-block', [function () {
                            // Show minicart dropdown dialog.
                            parentWindow.jQuery('[data-block="minicart"]')
                                .find('[data-role="dropdownDialog"]')
                                .dropdownDialog("open");
                        }]);
                    }

                    if (location.includes('/checkout')) {
                        setTimeout(function () {
                            window.parent.location.reload(true);
                        }, 2000)
                    } else {
                        finish();

                        if (isInModal && xhr.status === 200) {
                            setTimeout(function () {
                                // Close product modal.
                                parentWindow.jQuery('.product-quickview')
                                    .modal('closeModal');
                            }, 2000);
                        }
                    }
                },
                error: function (error) {
                    console.log(error.responseText);
                    finish();
                }
            });

            return false;
        });
    }
});
