define([
  'jquery',
  'Magento_Ui/js/modal/modal',
  'Magento_Customer/js/customer-data',
  'Amazingcat_ProductModal/js/modal',
], function ($, modal, customerData, productModal) {
  'use strict';

  $(document).on('update-mini-cart-block', function (event, callback) {
    var sections = ['cart'];
    customerData.invalidate(sections);
    customerData.reload(sections, true)
      .then(function () {
        if (callback) {
          callback();
        }
      });
  });

  var prepareModal = function (productId, quoteItemId = null, editStatus) {
    $.ajax({
      method: 'GET',
      url: '/productmodal/product/check',
      data: {
        product_id: productId
      },
      dataType: 'json',
      success: function (data) {
        if (data.status === 200) {
          openQuickViewModal(data.productUrl, productId, quoteItemId);
        } else {
          removeLoadGif(productId);
        }
      }
    });
  };

  var hash = window.location.hash;
  var reg = /product-(\d+)-(\w+)/;

  // Drop hash for link sharing
  history.pushState("", document.title, window.location.pathname
    + window.location.search);
  if (hash) {
    var productId = reg.exec(hash) ? reg.exec(hash)[1] : null;
    if (productId) {
      prepareModal(productId);
    }
  }

  var options = {
    type: 'product',
    customTpl: 'product',
    productTpl: '#product-template',
    responsive: true,
    innerScroll: false,
    title: '1',
    buttons: [{
      text: $.mage.__('Close'),
      class: 'close-modal',
      click: function () {
        // Drop hash for link sharing
        history.pushState("", document.title, window.location.pathname
          + window.location.search);
        this.closeModal();
      }
    }]
  };

  modal(options, $('#quickViewContainer'));

  var createIframe = function (productUrl, quoteItemId) {
    return $('<iframe />', {
      id: 'iFrame',
      src: productUrl + '?iframe=1&quote-item-id=' + quoteItemId
    });
  };

  var openQuickViewModal = function (productUrl, productId, quoteItemId) {
    var modalContainer = $("#quickViewContainer");
    modalContainer.html(createIframe(productUrl, quoteItemId));

    var iframe_selector = "#iFrame";

    $(iframe_selector).on("load", function () {
      modalContainer.addClass("product-quickview");
      modalContainer.modal('openModal');
      modalContainer.closest('.modal-product').css('z-index', 200);
      removeLoadGif(productId);

      productModal({
        productId: productId,
        quoteItemId: quoteItemId,
      }, $(iframe_selector).contents().find('#maincontent')[0]);
    });
  };

  var getLoadGif = function (product_id) {
    var span = $("#addToCartButton" + product_id).find('span');
    if (span) {
      $(span).empty();
      $(span).append('<i class="fas fa-spinner fa-spin"></i>');
    }
  };

  var removeLoadGif = function (product_id) {
    var span = $("#addToCartButton" + product_id).find('span');
    if (span) {
      $(span).empty();
      $(span).append('<i class="fas fa-shopping-cart"></i>');
    }
  };

  var isCheckout = function () {
    return window.parent.location.href.includes('/checkout');
  };

  return function (config, node) {
    var $node = $(node);
    var productId = $node.data('id');

    if (isCheckout) {
      $node.off("click").on("click", function (e) {
        e.preventDefault();

        var quoteItemId = $(this).data('quote-item-id');
        var editStatus =  $(this).data('edit-status');

        getLoadGif(productId);
        prepareModal(productId, quoteItemId, editStatus);
      });
    } else {
      $node.off("click").on("click", function (e) {
        e.preventDefault();

        getLoadGif(productId);
        prepareModal(productId);
      });
    }
  };
});
